@@ -2,7 +2,7 @@ sep.1z <-
 function(y, n, xmu.1, p.xmu, xsum.1, p.xsum, 
                    rid, EUID, nEU, prior1, prior2, prior.beta, prior.Sigma, 
                    prec.int, prec.DN, lambda.L1, lambda.L2,lambda.ARD,
-                   scale.unif, scale.halft, link, n.chain, inits) 
+                   scale.unif, scale.halft, link, n.chain, inits, seed) 
 { 
   dataIn <- vector("list",15)
   names(dataIn) <- c("n","y","xmu.1","p.xmu","xsum.1", "p.xsum",
@@ -25,9 +25,33 @@ function(y, n, xmu.1, p.xmu, xsum.1, p.xsum,
   dataIn[[12]] <- rid 
   dataIn[[13]] <- EUID
   dataIn[[14]] <- nEU
-    
-  init <- function( ){
-    list("tmp1" = rnorm(1,0,0.1),
+ 
+  
+  if(is.null(seed)){
+    init <- function( rngname, rngseed){
+      list("tmp1" = rnorm(1,0,0.1),
+           "tmp2" = rnorm(1,0,0.1),
+           
+           "b.tmp" = matrix(rnorm((p.xmu-1)*4,0,0.1),ncol=4),
+           "d.tmp" = matrix(rnorm((p.xsum-1)*4,0,0.1),ncol=4),
+           
+           "sigmab.L1" = runif((p.xmu-1),0,2), 
+           "sigmad.L1" = runif((p.xsum-1),0,2), 
+           
+           "taub.ARD" = runif((p.xmu-1),0,2), 
+           "taud.ARD" = runif((p.xsum-1),0,2), 
+           
+           "taub.L2" = runif(1,0,2), 
+           "taud.L2" = runif(1,0,2),
+           
+           "sigma1" = runif(1,0.25,1),
+           "scale2" = runif(1,0.25,1))}
+      inits.internal <- list(init( ));
+      if(n.chain >= 2) {
+        for(j in 2:n.chain) inits.internal <- c(inits.internal,list(init()))} 
+    } else{
+      init <- function(rngname, rngseed ){
+      list("tmp1" = rnorm(1,0,0.1),
          "tmp2" = rnorm(1,0,0.1),
          
          "b.tmp" = matrix(rnorm((p.xmu-1)*4,0,0.1),ncol=4),
@@ -43,11 +67,17 @@ function(y, n, xmu.1, p.xmu, xsum.1, p.xsum,
          "taud.L2" = runif(1,0,2),
          
          "sigma1" = runif(1,0.25,1),
-         "scale2" = runif(1,0.25,1))}    
+         "scale2" = runif(1,0.25,1),
+         
+         .RNG.name = rngname, 
+         .RNG.seed = rngseed)}    
 
-  inits.internal <- list(init( ));
+  set.seed(seed[1]); inits.internal <- list(init("base::Super-Duper", seed[1]));
   if(n.chain >= 2) {
-    for(j in 2:n.chain) inits.internal <- c(inits.internal,list(init( ))) }  
+    for(j in 2:n.chain){ 
+      set.seed(seed[j]); 
+      inits.internal <- c(inits.internal,list(init("base::Wichmann-Hill",seed[j])))}}  
+    }
   
   if(!is.null(inits)){
     
